@@ -42,29 +42,29 @@ testQuery db = do
   bracket (PG.connectPostgreSQL theConnectionString) PG.close $
     \conn -> void $ PG.execute_ conn "INSERT INTO foo1 (id) VALUES (1)"
 
-setupCache :: IO CacheResources
+setupCache :: IO Cache
 setupCache = do
   cacheInfo <- setupInitDbCache defaultCacheConfig
-  void (withConfig (defaultConfig <> cacheResourcesToConfig cacheInfo) (const $ pure ()))
+  void (withConfig (defaultConfig <> cacheConfig cacheInfo) (const $ pure ()))
   pure cacheInfo
 
 setupWithCache :: (Config -> Benchmark) -> Benchmark
-setupWithCache f = envWithCleanup setupCache cleanupInitDbCache $ f . (defaultConfig <>) . cacheResourcesToConfig
+setupWithCache f = envWithCleanup setupCache cleanupInitDbCache $ f . (defaultConfig <>) . cacheConfig
 
-setupCacheAndSP :: IO (CacheResources, Snapshot, Once Config)
+setupCacheAndSP :: IO (Cache, Snapshot, Once Config)
 setupCacheAndSP = do
   cacheInfo <- setupCache
-  let cacheConfig = defaultConfig <> cacheResourcesToConfig cacheInfo
-  sp <- either throwIO pure <=< withConfig cacheConfig $ \db -> do
+  let theCacheConfig = defaultConfig <> cacheConfig cacheInfo
+  sp <- either throwIO pure <=< withConfig theCacheConfig $ \db -> do
     migrateDb db
     either throwIO pure =<< takeSnapshot Temporary db
 
-  let theConfig = defaultConfig <> snapshotConfig sp <> cacheConfig
+  let theConfig = defaultConfig <> snapshotConfig sp <> theCacheConfig
 
 
   pure (cacheInfo, sp, Once theConfig)
 
-cleanupCacheAndSP :: (CacheResources, Snapshot, Once Config) -> IO ()
+cleanupCacheAndSP :: (Cache, Snapshot, Once Config) -> IO ()
 cleanupCacheAndSP (x, y, _) = cleanupSnapshot y >> cleanupInitDbCache x
 
 setupWithCacheAndSP :: (Config -> Benchmark) -> Benchmark
@@ -90,12 +90,12 @@ main = defaultMain
 
 -}
 
-    setupWithCache $ \cacheConfig -> do
-      bench "with migrate 10x and cache" $ whnfIO $ withConfig cacheConfig $ \_ -> do
-        replicateM_ 10 $ withConfig cacheConfig $ \db ->
+    setupWithCache $ \theCacheConfig -> do
+      bench "with migrate 10x and cache" $ whnfIO $ withConfig theCacheConfig $ \_ -> do
+        replicateM_ 10 $ withConfig theCacheConfig $ \db ->
           migrateDb db >> testQuery db
 
-  , setupWithCache $ \cacheConfig -> bench "withSnapshot migrate 10x and cache" $ whnfIO $ withConfig cacheConfig $ \db -> do
+  , setupWithCache $ \theCacheConfig -> bench "withSnapshot migrate 10x and cache" $ whnfIO $ withConfig theCacheConfig $ \db -> do
       migrateDb db
       void $ withSnapshot Temporary db $ \snapshotDir -> do
         let theSnapshotConfig = defaultConfig <> snapshotConfig snapshotDir
