@@ -14,7 +14,6 @@ import           Control.Monad (void)
 import           Control.Monad.Trans.Cont
 import           Data.ByteString (ByteString)
 import qualified Data.Map.Strict as Map
-import qualified Database.PostgreSQL.Simple as PG
 import qualified Database.PostgreSQL.Simple.Options as Client
 import           GHC.Generics
 import           System.Exit (ExitCode(..))
@@ -23,15 +22,14 @@ import           System.Process
 import           Text.PrettyPrint.ANSI.Leijen hiding ((<$>))
 
 -- | Handle for holding temporary resources, the @postgres@ process handle
---   and postgres connection information. The 'DB' also includes the
+--   and @postgres@ connection information. The 'DB' also includes the
 --   final plan used to start @initdb@, @createdb@ and
---   @postgres@. See 'toConnectionString' or 'toConnectionOptions'
---   for converting a 'DB' to postgresql connection string.
+--   @postgres@.
 --
 --   @since 1.12.0.0
 data DB = DB
   { dbResources :: Resources
-  -- ^ Temporary resources and the final 'CompletePlan'.
+  -- ^ Temporary resources and the final 'Plan'.
   , dbPostgresProcess :: PostgresProcess
   -- ^ @postgres@ process handle and the connection options.
   }
@@ -76,15 +74,15 @@ If you are using 'with' or 'withConfig' this function will
 not modify the 'DB' that is passed for cleanup. You will
 need to setup your own bracket like
 
- @
-    bracket (fmap 'makeDataDirPermanent' 'start') (either mempty 'stop')
- @
+@
+bracket (fmap 'makeDataDirectoryPermanent' 'start') (either mempty 'stop')
+@
 
 
-@since 1.12.0.0
+@since 1.24.0.0
 -}
-makeDataDirPermanent :: DB -> DB
-makeDataDirPermanent db = db
+makeDataDirectoryPermanent :: DB -> DB
+makeDataDirectoryPermanent db = db
   { dbResources = makeResourcesDataDirPermanent $ dbResources db
   }
 
@@ -97,26 +95,26 @@ toTemporaryDirectory = resourcesTemporaryDir . dbResources
 {-|
 Get the final @postgresql.conf@
 
-@since 1.22.0.0
+@since 1.25.0.0
 -}
-toPostgresqlConf :: DB -> String
-toPostgresqlConf = completePlanConfig . resourcesPlan . dbResources
+toPostgresqlConfigFile :: DB -> String
+toPostgresqlConfigFile = completePlanConfig . resourcesPlan . dbResources
 -------------------------------------------------------------------------------
 -- Life Cycle Management
 -------------------------------------------------------------------------------
 {-|
 The fastest config we can make.
 
- @
-   shared_buffers = 12MB
-   fsync = off
-   synchronous_commit = off
-   full_page_writes = off
-   log_min_messages = PANIC
-   log_min_error_statement = PANIC
-   log_statement = none
-   client_min_messages = ERROR
- @
+@
+shared_buffers = 12MB
+fsync = off
+synchronous_commit = off
+full_page_writes = off
+log_min_messages = PANIC
+log_min_error_statement = PANIC
+log_statement = none
+client_min_messages = ERROR
+@
 
 @since 1.21.0.0
 -}
@@ -140,15 +138,15 @@ The default configuration. This will create a database called \"postgres\"
  Additionally it will use the following \"postgresql.conf\"
  which is optimized for performance.
 
- @
-   shared_buffers = 12MB
-   fsync = off
-   synchronous_commit = off
-   full_page_writes = off
-   log_min_messages = PANIC
-   log_min_error_statement = PANIC
-   log_statement = none
-   client_min_messages = ERROR
+@
+shared_buffers = 12MB
+fsync = off
+synchronous_commit = off
+full_page_writes = off
+log_min_messages = PANIC
+log_min_error_statement = PANIC
+log_statement = none
+client_min_messages = ERROR
 @
 
 'defaultConfig' also passes the @--no-sync@ flag to @initdb@.
@@ -167,17 +165,17 @@ The 'defaultConfig' redirects all output to @\/dev\/null@. See
 To append additional lines to \"postgresql.conf\" file create a
 custom 'Config' like the following.
 
- @
-  custom = defaultConfig <> mempty
-    { 'postgresConfigFile' =
-        [ ("wal_level, "replica")
-        , ("archive_mode", on")
-        , ("max_wal_senders", "2")
-        , ("fsync", "on")
-        , ("synchronous_commit", "on")
-        ]
-    }
- @
+@
+custom = defaultConfig <> mempty
+  { 'postgresConfigFile' =
+      [ ("wal_level, "replica")
+      , ("archive_mode", on")
+      , ("max_wal_senders", "2")
+      , ("fsync", "on")
+      , ("synchronous_commit", "on")
+      ]
+  }
+@
 
 
  This is common enough there is `defaultPostgresConf` which
@@ -273,34 +271,32 @@ Create zero or more temporary resources and use them to make a 'Config'.
 The passed in config is inspected and a generated config is created.
 The final config is built by
 
- @
-   generated '<>' extra
- @
+@
+generated '<>' extra
+@
 
 Based on the value of 'socketDirectory' a \"postgresql.conf\" is created with:
 
- @
-   listen_addresses = '127.0.0.1, ::1'
-   unix_socket_directories = \'SOCKET_DIRECTORY\'
- @
+@
+listen_addresses = '127.0.0.1, ::1'
+unix_socket_directories = \'SOCKET_DIRECTORY\'
+@
 
-Additionally the @generated@ `Config` also does the following:
+Additionally the @generated@ `Config` also:
 
 * Sets a `connectionTimeout` of one minute.
-* Logs internal `Event`s.
-* Sets the processes to use the standard input and output handles.
-* Sets the 'dataDirectory' to file path generated from 'dataDirectory'.
+* Redirects output to @\/dev\/null@.
 
 All of these values can be overrided by the @extra@ config.
 
 The returned 'DB' requires cleanup. `startConfig` should be
 used with a `bracket` and 'stop', e.g.
 
- @
-   `withConfig` :: `Config` -> (`DB` -> IO a) -> IO (Either `StartError` a)
-   'withConfig' plan f = `bracket` (`startConfig` plan) (either mempty `stop`) $
-      either (pure . Left) (fmap Right . f)
- @
+@
+`withConfig` :: `Config` -> (`DB` -> IO a) -> IO (Either `StartError` a)
+'withConfig' plan f = `bracket` (`startConfig` plan) (either mempty `stop`) $
+  either (pure . Left) (fmap Right . f)
+@
 
 or just use 'withConfig'. If you are calling 'startConfig' you
 probably want 'withConfig' anyway.
@@ -350,27 +346,18 @@ stopPostgres = stopPlan . dbPostgresProcess
 stopPostgresGracefully :: DB -> IO ExitCode
 stopPostgresGracefully = stopPostgresProcess True . dbPostgresProcess
 
--- | Restart the @postgres@ from 'DB' using the prior 'Config'.
+-- | Restart the @postgres@ from 'DB' using the prior 'Config'. This
+--   will also start an instance previously stoppped with 'stopPostgres'.
 --
 --   @since 1.12.0.0
 restart :: DB -> IO (Either StartError DB)
 restart db@DB{..} = try $ do
   void $ stopPostgres db
-  let CompletePlan{..} = resourcesPlan dbResources
+  let Plan{..} = resourcesPlan dbResources
       startAction = startPostgresProcess completePlanConnectionTimeout completePlanLogger
         completePlanPostgres
   bracketOnError startAction stopPlan $ \result ->
     pure $ db { dbPostgresProcess = result }
-
--- | Reload the configuration file without shutting down. Calls
---   @pg_reload_conf()@.
---
---   @since 1.12.0.0
-reloadConfig :: DB -> IO ()
-reloadConfig db =
-  bracket (PG.connectPostgreSQL $ toConnectionString db) PG.close $ \conn ->
-    (void :: IO [PG.Only Bool] -> IO ()) $
-      PG.query_ conn "SELECT pg_reload_conf()"
 -------------------------------------------------------------------------------
 -- Exception safe interface
 -------------------------------------------------------------------------------
@@ -381,7 +368,7 @@ details. Calls 'stop' even in the face of exceptions.
 @since 1.21.0.0
 -}
 withConfig :: Config
-         -- ^ @extra@. 'Config' combined with the generated 'Config'. See
+         -- ^ The @extra@ 'Config' combined with the @generated@ 'Config'. See
          -- 'startConfig' for more info.
          -> (DB -> IO a)
          -- ^ @action@ continuation.
@@ -391,9 +378,9 @@ withConfig extra f = bracket (startConfig extra) (either mempty stop) $
 
 {-| Default expectation safe interface. Equivalent to
 
- @
-   'with' = 'withConfig' 'defaultConfig'
- @
+@
+'with' = 'withConfig' 'defaultConfig'
+@
 
 @since 1.21.0.0
 -}
@@ -432,7 +419,7 @@ prettyPrintDB = show . pretty
 {-|
 Configuration for the @initdb@ data directory cache.
 
-@since 1.20.0.0
+@since 1.25.0.0
 -}
 data CacheConfig = CacheConfig
   { cacheTemporaryDirectory :: FilePath
@@ -452,9 +439,9 @@ data CacheConfig = CacheConfig
 {-|
 A handle to cache temporary resources and configuration.
 
-@since 1.20.0.0
+@since 1.25.0.0
 -}
-data CacheResources = CacheResources
+data Cache = Cache
   { cacheResourcesCow :: Bool
   , cacheResourcesDirectory :: CompleteDirectoryType
   } deriving stock (Generic)
@@ -487,7 +474,7 @@ It sets 'cacheDirectoryType' to 'Permanent' @~\/.tmp-postgres@ and
 'cacheTemporaryDirectory' to @\/tmp@ (but this is not used when
 'Permanent' is set).
 
-@since 1.19.0.0
+@since 1.25.0.0
 -}
 defaultCacheConfig :: CacheConfig
 defaultCacheConfig = CacheConfig
@@ -496,10 +483,14 @@ defaultCacheConfig = CacheConfig
   , cacheUseCopyOnWrite = cowCheck
   }
 
--- | Setup the @initdb@ cache folder.
+{-|
+Setup the @initdb@ cache folder.
+
+@since 1.25.0.0
+-}
 setupInitDbCache
   :: CacheConfig
-  -> IO CacheResources
+  -> IO Cache
 setupInitDbCache CacheConfig {..} =
   bracketOnError
     (setupDirectoryType
@@ -507,14 +498,14 @@ setupInitDbCache CacheConfig {..} =
       "tmp-postgres-cache"
       cacheDirectoryType
     )
-    cleanupDirectoryType $ pure . CacheResources cacheUseCopyOnWrite
+    cleanupDirectoryType $ pure . Cache cacheUseCopyOnWrite
 
 {-|
 Cleanup the cache directory if it was 'Temporary'.
 
-@since 1.20.0.0
+@since 1.25.0.0
 -}
-cleanupInitDbCache :: CacheResources -> IO ()
+cleanupInitDbCache :: Cache -> IO ()
 cleanupInitDbCache = cleanupDirectoryType . cacheResourcesDirectory
 
 {-|
@@ -523,15 +514,15 @@ Enable @initdb@ data directory caching. This can lead to a 4x speedup.
 Exception safe version of 'setupInitDbCache'. Equivalent to
 
 @
-   'withDbCacheConfig' = bracket ('setupInitDbCache' config) 'cleanupInitDbCache'
+'withDbCacheConfig' = bracket ('setupInitDbCache' config) 'cleanupInitDbCache'
 @
 
-@since 1.20.0.0
+@since 1.25.0.0
 -}
 withDbCacheConfig
   :: CacheConfig
   -- ^ Configuration
-  -> (CacheResources -> IO a)
+  -> (Cache -> IO a)
   -- ^ action for which caching is enabled
   -> IO a
 withDbCacheConfig config =
@@ -541,18 +532,26 @@ withDbCacheConfig config =
 Equivalent to 'withDbCacheConfig' with the 'CacheConfig'
 'defaultCacheConfig' makes.
 
-@since 1.20.0.0
+Here is an example using caching:
+
+@
+withDbCache $ \\cache -> do
+  withCache (cacheConfig cache) $ \\db -> ...
+  withCache (cacheConfig cache) $ \\db -> ...
+@
+
+@since 1.25.0.0
 -}
-withDbCache :: (CacheResources -> IO a) -> IO a
+withDbCache :: (Cache -> IO a) -> IO a
 withDbCache = withDbCacheConfig defaultCacheConfig
 
 {-|
 Helper to make a 'Config' out of caching info.
 
-@since 1.22.0.0
+@since 1.25.0.0
 -}
-cacheResourcesToConfig :: CacheResources -> Config
-cacheResourcesToConfig CacheResources {..} = mempty
+cacheConfig :: Cache -> Config
+cacheConfig Cache {..} = mempty
   { initDbCache = pure $ pure
       (cacheResourcesCow, toFilePath cacheResourcesDirectory)
   }
@@ -616,6 +615,17 @@ Exception safe method for taking a file system level copy of the database cluste
 Snapshots are useful if you would like to start every test from a migrated database
 and the migration process is more time consuming then copying the additional data.
 
+Here is an example with caching and snapshots:
+
+@
+withDbCache $ \\cache -> withConfig (cacheConfig cache) $ \\db ->
+  migrate db
+  withSnapshot Temporary db $ \\snapshot -> do
+    withConfig (snapshotConfig db) $ \\migratedDb -> ...
+    withConfig (snapshotConfig db) $ \\migratedDb -> ...
+    withConfig (snapshotConfig db) $ \\migratedDb -> ...
+@
+
 @since 1.20.0.0
 -}
 withSnapshot
