@@ -1,13 +1,13 @@
 {-# OPTIONS_HADDOCK prune #-}
 {-| This module provides types and functions for combining partial
-    configs into a complete configs to ultimately make a 'CompletePlan'.
+    configs into a complete configs to ultimately make a 'Plan'.
 
     This module has two classes of types.
 
     Types like 'ProcessConfig' that could be used by any
     library that  needs to combine process options.
 
-    Finally it has types and functions for creating 'CompletePlan's that
+    Finally it has types and functions for creating 'Plan's that
     use temporary resources. This is used to create the default
     behavior of 'Database.Postgres.Temp.startConfig' and related
     functions.
@@ -379,12 +379,17 @@ rmDirIgnoreErrors mainDir = do
   let ignoreDirIsMissing e
         | isDoesNotExistError e = return ()
         | otherwise = throwIO e
-  -- I'm trying to prevent new files getting added
-  -- to the dir as I am deleting the files.
-  let newName = mainDir <> "_removing"
-  handle ignoreDirIsMissing $ uninterruptibleMask_ $ do
-    renameDirectory mainDir newName
-    removeDirectoryRecursive newName
+
+  -- Files are continued to be written after the delete starts. This
+  -- seems to fix it. #122
+  -- TODO come up with a better way to deal with this. Probably
+  -- need to lock the directories recursively before deleting.
+  handle ignoreDirIsMissing $
+    try (removePathForcibly mainDir) >>= \case
+    Left (_ :: IOError) -> try (removePathForcibly mainDir) >>= \case
+      Left (_ :: IOError) -> removePathForcibly mainDir
+      Right _ -> pure ()
+    Right _ -> pure ()
 
 -- | Either remove a 'CTemporary' directory or do nothing to a 'CPermanent'
 -- one.
@@ -393,7 +398,6 @@ cleanupDirectoryType = \case
   CPermanent _ -> pure ()
   CTemporary filePath -> rmDirIgnoreErrors filePath
 
-
 -- | Turn a 'Config' into a 'CompletePostgresPlan'. Fails if any
 --   values are missing.
 completePostgresPlan :: [(String, String)] -> Config -> Either [String] CompletePostgresPlan
@@ -405,13 +409,12 @@ completePostgresPlan envs Config {..} = runErrors $ do
 
   pure CompletePostgresPlan {..}
 
-
 flattenConfig :: [(String, String)] -> String
 flattenConfig = unlines . map (\(x, y) -> x <> "=" <> y) .
   Map.toList . Map.fromList
 
--- | Turn a 'Config' into a 'CompletePlan'. Fails if any values are missing.
-completePlan :: [(String, String)] -> String -> Config -> Either [String] CompletePlan
+-- | Turn a 'Config' into a 'Plan'. Fails if any values are missing.
+completePlan :: [(String, String)] -> String -> Config -> Either [String] Plan
 completePlan envs dataDirectoryString config@Config {..} = do
   (   completePlanLogger
     , completePlanInitDb
@@ -435,7 +438,7 @@ completePlan envs dataDirectoryString config@Config {..} = do
       completePlanCopy = completeCopyDirectory completePlanDataDirectory <$>
         join (getLast copyConfig)
 
-  pure CompletePlan {..}
+  pure Plan {..}
 
 -- Returns 'True' if the 'Config' has a
 -- 'Just' 'initDbConfig'.
@@ -449,16 +452,25 @@ hasCreateDb Config {..} = isJust $ getAccum createDbConfig
 
 -- | The high level options for overriding default behavior.
 --
---   @since 1.16.0.0
+--   @since 1.22.0.0
 data Config = Config
   { logger :: Last Logger
+  -- ^ Internal 'Event' logger.
   , initDbConfig :: Accum ProcessConfig
+  -- ^ Monoid for accumulating @initdb@ configuration.
   , copyConfig :: Last (Maybe CopyDirectoryCommand)
+  -- ^ An optional data directory copy command.
   , createDbConfig :: Accum ProcessConfig
+  -- ^ Monoid for accumulating @createdb@ configuration.
   , postgresConfig :: ProcessConfig
+  -- ^ The @postgres@ process configuration.
   , connectionOptions :: Client.Options
+  -- ^ The additional client connection options.
   , postgresConfigFile :: [(String, String)]
+  -- ^ The @postgresql.conf@ configuration file.
   , connectionTimeout :: Last Int
+  -- ^ The amount of microseconds to attempt to connect
+  --   to @postgres@ before throwing 'ConnectionTimedOut'
   , socketDirectory  :: DirectoryType
   -- ^ Override the default temporary UNIX socket directory by setting this.
   , dataDirectory :: DirectoryType
@@ -629,8 +641,8 @@ addDataDirectory theDataDirectory x = x
       ("--pgdata=" <> theDataDirectory) : completeProcessConfigCmdLine x
   }
 
-cachePlan :: CompletePlan -> Bool -> FilePath -> IO CompletePlan
-cachePlan plan@CompletePlan {..} cow cacheDirectory = case completePlanInitDb of
+cachePlan :: Plan -> Bool -> FilePath -> IO Plan
+cachePlan plan@Plan {..} cow cacheDirectory = case completePlanInitDb of
   Nothing -> pure plan
   Just theConfig -> do
     let (mtheDataDirectory, clearedConfig) = splitDataDirectory theConfig
@@ -736,7 +748,7 @@ setupConfig config@Config {..} = evalContT $ do
         (toFilePath resourcesDataDir)
       finalPlan = hostAndDir <> config
   uncachedPlan <- lift $
-    either (throwIO . CompletePlanFailed (show $ pretty finalPlan)) pure $
+    either (throwIO . PlanFailed (show $ pretty finalPlan)) pure $
       completePlan envs (toFilePath resourcesDataDir) finalPlan
   resourcesPlan <- lift $ maybe (pure uncachedPlan) (uncurry $ cachePlan uncachedPlan) resourcesInitDbCache
   pure Resources {..}
@@ -754,13 +766,13 @@ prettyPrintConfig :: Config -> String
 prettyPrintConfig = show . pretty
 
 -- | 'Resources' holds a description of the temporary folders (if there are any)
---   and includes the final 'CompletePlan' that can be used with 'startPlan'.
+--   and includes the final 'Plan' that can be used with 'startPlan'.
 --   See 'setupConfig' for an example of how to create a 'Resources'.
 --
 --   @since 1.12.0.0
 data Resources = Resources
-  { resourcesPlan    :: CompletePlan
-  -- ^ Final 'CompletePlan'. See 'startPlan' for information on 'CompletePlan's.
+  { resourcesPlan    :: Plan
+  -- ^ Final 'Plan'. See 'startPlan' for information on 'Plan's.
   , resourcesSocketDirectory :: CompleteDirectoryType
   -- ^ The used to potentially cleanup the temporary unix socket directory.
   , resourcesDataDir :: CompleteDirectoryType
@@ -866,3 +878,4 @@ hostToSocketClass :: String -> DirectoryType
 hostToSocketClass hostOrSocketPath = case hostOrSocketPath of
   '/' : _ -> Permanent hostOrSocketPath
   _ -> Temporary
+
