@@ -314,7 +314,7 @@ happyPaths = describe "succeeds with" $ do
   it "makeResourcesDataDirPermanent works" $
     withTempDirectory "/tmp" "tmp-postgres-make-premanent" $ \dirPath -> do
        let config = defaultConfig { temporaryDirectory = pure dirPath }
-       pathToCheck <- bracket (either throwIO (pure . makeDataDirPermanent) =<< startConfig config) stop $
+       pathToCheck <- bracket (either throwIO (pure . makeDataDirectoryPermanent) =<< startConfig config) stop $
         pure . toDataDirectory
        doesDirectoryExist pathToCheck >>= \case
          True -> pure ()
@@ -323,13 +323,13 @@ happyPaths = describe "succeeds with" $ do
   it "withDbCacheConfig actually caches the config and cleans up" $
     withTempDirectory "/tmp" "tmp-postgres-cache-test" $ \dirPath -> do
       let config = defaultConfig { temporaryDirectory = pure dirPath }
-          cacheConfig = CacheConfig
+          theCacheConfig = CacheConfig
             { cacheTemporaryDirectory = dirPath
             , cacheDirectoryType      = Temporary
             , cacheUseCopyOnWrite     = True
             }
-      withDbCacheConfig cacheConfig $ \cacheInfo -> do
-        withConfig' (config <> cacheResourcesToConfig cacheInfo) $ const $ pure ()
+      withDbCacheConfig theCacheConfig $ \cacheInfo -> do
+        withConfig' (config <> cacheConfig cacheInfo) $ const $ pure ()
         -- see if there is a cache
         tmpFiles <- listDirectory dirPath
 
@@ -355,7 +355,7 @@ happyPaths = describe "succeeds with" $ do
           xs -> fail $ "expected a single version directory but got " <> show xs
 
         -- add a file to look for later
-        withConfig' (config <> cacheResourcesToConfig cacheInfo) $ \db -> do
+        withConfig' (config <> cacheConfig cacheInfo) $ \db -> do
           -- see if the file is in the data directory
           let theDataDirectory = toDataDirectory db
           xs <- listDirectory theDataDirectory
@@ -372,11 +372,11 @@ happyPaths = describe "succeeds with" $ do
 
   it "withDbCache seems to work" $
     withDbCache $ \cacheInfo ->
-      either throwIO pure =<< withConfig (cacheResourcesToConfig cacheInfo) assertConnection
+      either throwIO pure =<< withConfig (cacheConfig cacheInfo) assertConnection
 
   it "postgresql.conf append last wins" $
     withConfig' (defaultPostgresConf [("fsync", "on")]) $ \db -> do
-      toPostgresqlConf db `shouldContain` "fsync=on"
+      toPostgresqlConfigFile db `shouldContain` "fsync=on"
 --
 -- Error Plans. Can't be combined. Just list them out inline since they can't be combined
 --
@@ -509,7 +509,7 @@ errorPaths = describe "fails when" $ do
   it "throws if initdb is not on the path" $ do
     path <-  getEnv "PATH"
 
-    bracket (setEnv "PATH" "/foo") (const $ setEnv "PATH" path) $ \_ ->
+    bracket (setEnv "PATH" "/bin") (const $ setEnv "PATH" path) $ \_ ->
       withConfig defaultConfig (const $ pure ())
         `shouldThrow` isDoesNotExistError
 
@@ -517,10 +517,14 @@ errorPaths = describe "fails when" $ do
     withTempDirectory "/tmp" "createdb-not-on-path-test" $ \dir -> do
       Just initDbPath   <- findExecutable "initdb"
       Just postgresPath <- findExecutable "postgres"
+      Just rmPath       <- findExecutable "rm"
+      Just chmod        <- findExecutable "chmod"
 
       -- create symlinks
       createSymbolicLink initDbPath $ dir <> "/initdb"
       createSymbolicLink postgresPath $ dir <> "/postgres"
+      createSymbolicLink rmPath $ dir <> "/rm"
+      createSymbolicLink chmod $ dir <> "/chmod"
 
       path <-  getEnv "PATH"
 
@@ -566,19 +570,6 @@ spec = do
     PG.connectPostgreSQL (toConnectionString db) `shouldThrow`
       (\(_ :: IOError) -> True)
 
-  it "reloadConfig works" $ withConfig' defaultConfig $ \db -> do
-    let
-      dataDir = toDataDirectory db
-      expectedDuration = "100ms"
-      extraConfig = "log_min_duration_statement='" <> expectedDuration <> "'"
-    appendFile (dataDir ++ "/postgresql.conf") $ extraConfig
-
-    reloadConfig db
-
-    withConn db $ \conn -> do
-      [PG.Only actualDuration] <- PG.query_ conn "SHOW log_min_duration_statement"
-      actualDuration `shouldBe` expectedDuration
-
   -- Not a great test but don't want to be too rigid
   let createdbPlan = optionsToDefaultConfig mempty { Client.dbname = pure "newdb" }
   it "prettyPrintConfig seems to work" $ do
@@ -637,7 +628,9 @@ spec = do
 
       createDirectory walArchiveDir
 
-      reloadConfig db
+      bracket (PG.connectPostgreSQL $ toConnectionString db) PG.close $ \conn ->
+        (void :: IO [PG.Only Bool] -> IO ()) $
+          PG.query_ conn "SELECT pg_reload_conf()"
 
       let Just port = getLast $ Client.port $ postgresProcessClientOptions dbPostgresProcess
           Just host = getLast $ Client.host $ postgresProcessClientOptions dbPostgresProcess
